@@ -245,10 +245,31 @@ Clear the session:
         $self->req->session( {} );
     }
 
-Delete session value:
+=head3 Common tasks with sessions
+
+=over
+
+=item Initialize file sessions
+
+In your config file:
+
+    middleware => ['Session'],
+    middleware_init => {
+        Session => {
+            store => 'File'
+        }
+    }
+
+=item Delete session value
 
     delete $self->req->session->{'useless'};
 
+=item Remove all session values
+
+    $self->req->session( {} );
+
+=back
+
 =head2 is_ajax
 
 Returns true if the request was called with C<XMLHttpRequest>.
